@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, Optional
 
 from mininode._requests import HttpRequest
 
@@ -9,8 +9,8 @@ class BaseAPI:
         self.group_id = group_id
         self.aes_key = aes_key
 
-    def _get(self, endpoint: str, payload: Dict = {}):
+    def _get(self, endpoint: str, payload: Optional[Dict] = None):
         return self._http.get(endpoint, payload)
 
-    def _post(self, endpoint: str, payload: Dict = {}):
+    def _post(self, endpoint: str, payload: Optional[Dict] = None):
         return self._http.post(endpoint, payload)
